import typing

import typing_extensions

_list = list

@typing.type_check_only
class DatabaseInstance(typing_extensions.TypedDict, total=False):
    databaseUrl: str
    name: str
    project: str
    state: typing_extensions.Literal[
        "LIFECYCLE_STATE_UNSPECIFIED", "ACTIVE", "DISABLED", "DELETED"
    ]
    type: typing_extensions.Literal[
        "DATABASE_INSTANCE_TYPE_UNSPECIFIED", "DEFAULT_DATABASE", "USER_DATABASE"
    ]

@typing.type_check_only
class DisableDatabaseInstanceRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ListDatabaseInstancesResponse(typing_extensions.TypedDict, total=False):
    instances: _list[DatabaseInstance]
    nextPageToken: str

@typing.type_check_only
class ReenableDatabaseInstanceRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class UndeleteDatabaseInstanceRequest(typing_extensions.TypedDict, total=False): ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class AdSenseHostResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class AccountsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class AdclientsResource(googleapiclient.discovery.Resource):
            def get(
                self, *, accountId: str, adClientId: str, **kwargs: typing.Any
            ) -> AdClientHttpRequest: ...
            def list(
                self,
                *,
                accountId: str,
                maxResults: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> AdClientsHttpRequest: ...
            def list_next(
                self,
                previous_request: AdClientsHttpRequest,
                previous_response: AdClients,
            ) -> AdClientsHttpRequest | None: ...

        @typing.type_check_only
        class AdunitsResource(googleapiclient.discovery.Resource):
            def delete(
                self,
                *,
                accountId: str,
                adClientId: str,
                adUnitId: str,
                **kwargs: typing.Any
            ) -> AdUnitHttpRequest: ...
            def get(
                self,
                *,
                accountId: str,
                adClientId: str,
                adUnitId: str,
                **kwargs: typing.Any
            ) -> AdUnitHttpRequest: ...
            def getAdCode(
                self,
                *,
                accountId: str,
                adClientId: str,
                adUnitId: str,
                hostCustomChannelId: str | _list[str] = ...,
                **kwargs: typing.Any
            ) -> AdCodeHttpRequest: ...
            def insert(
                self,
                *,
                accountId: str,
                adClientId: str,
                body: AdUnit = ...,
                **kwargs: typing.Any
            ) -> AdUnitHttpRequest: ...
            def list(
                self,
                *,
                accountId: str,
                adClientId: str,
                includeInactive: bool = ...,
                maxResults: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> AdUnitsHttpRequest: ...
            def list_next(
                self, previous_request: AdUnitsHttpRequest, previous_response: AdUnits
            ) -> AdUnitsHttpRequest | None: ...
            def patch(
                self,
                *,
                accountId: str,
                adClientId: str,
                adUnitId: str,
                body: AdUnit = ...,
                **kwargs: typing.Any
            ) -> AdUnitHttpRequest: ...
            def update(
                self,
                *,
                accountId: str,
                adClientId: str,
                body: AdUnit = ...,
                **kwargs: typing.Any
            ) -> AdUnitHttpRequest: ...

        @typing.type_check_only
        class ReportsResource(googleapiclient.discovery.Resource):
            def generate(
                self,
                *,
                accountId: str,
                startDate: str,
                endDate: str,
                dimension: str | _list[str] = ...,
                filter: str | _list[str] = ...,
                locale: str = ...,
                maxResults: int = ...,
                metric: str | _list[str] = ...,
                sort: str | _list[str] = ...,
                startIndex: int = ...,
                **kwargs: typing.Any
            ) -> ReportHttpRequest: ...

        def get(
            self, *, accountId: str, **kwargs: typing.Any
        ) -> AccountHttpRequest: ...
        def list(
            self, *, filterAdClientId: str | _list[str], **kwargs: typing.Any
        ) -> AccountsHttpRequest: ...
        def adclients(self) -> AdclientsResource: ...
        def adunits(self) -> AdunitsResource: ...
        def reports(self) -> ReportsResource: ...

    @typing.type_check_only
    class AdclientsResource(googleapiclient.discovery.Resource):
        def get(
            self, *, adClientId: str, **kwargs: typing.Any
        ) -> AdClientHttpRequest: ...
        def list(
            self, *, maxResults: int = ..., pageToken: str = ..., **kwargs: typing.Any
        ) -> AdClientsHttpRequest: ...
        def list_next(
            self, previous_request: AdClientsHttpRequest, previous_response: AdClients
        ) -> AdClientsHttpRequest | None: ...

    @typing.type_check_only
    class AssociationsessionsResource(googleapiclient.discovery.Resource):
        def start(
            self,
            *,
            productCode: typing_extensions.Literal["AFC", "AFG", "AFMC", "AFS", "AFV"]
            | _list[typing_extensions.Literal["AFC", "AFG", "AFMC", "AFS", "AFV"]],
            websiteUrl: str,
            callbackUrl: str = ...,
            userLocale: str = ...,
            websiteLocale: str = ...,
            **kwargs: typing.Any
        ) -> AssociationSessionHttpRequest: ...
        def verify(
            self, *, token: str, **kwargs: typing.Any
        ) -> AssociationSessionHttpRequest: ...

    @typing.type_check_only
    class CustomchannelsResource(googleapiclient.discovery.Resource):
        def delete(
            self, *, adClientId: str, customChannelId: str, **kwargs: typing.Any
        ) -> CustomChannelHttpRequest: ...
        def get(
            self, *, adClientId: str, customChannelId: str, **kwargs: typing.Any
        ) -> CustomChannelHttpRequest: ...
        def insert(
            self, *, adClientId: str, body: CustomChannel = ..., **kwargs: typing.Any
        ) -> CustomChannelHttpRequest: ...
        def list(
            self,
            *,
            adClientId: str,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> CustomChannelsHttpRequest: ...
        def list_next(
            self,
            previous_request: CustomChannelsHttpRequest,
            previous_response: CustomChannels,
        ) -> CustomChannelsHttpRequest | None: ...
        def patch(
            self,
            *,
            adClientId: str,
            customChannelId: str,
            body: CustomChannel = ...,
            **kwargs: typing.Any
        ) -> CustomChannelHttpRequest: ...
        def update(
            self, *, adClientId: str, body: CustomChannel = ..., **kwargs: typing.Any
        ) -> CustomChannelHttpRequest: ...

    @typing.type_check_only
    class ReportsResource(googleapiclient.discovery.Resource):
        def generate(
            self,
            *,
            startDate: str,
            endDate: str,
            dimension: str | _list[str] = ...,
            filter: str | _list[str] = ...,
            locale: str = ...,
            maxResults: int = ...,
            metric: str | _list[str] = ...,
            sort: str | _list[str] = ...,
            startIndex: int = ...,
            **kwargs: typing.Any
        ) -> ReportHttpRequest: ...

    @typing.type_check_only
    class UrlchannelsResource(googleapiclient.discovery.Resource):
        def delete(
            self, *, adClientId: str, urlChannelId: str, **kwargs: typing.Any
        ) -> UrlChannelHttpRequest: ...
        def insert(
            self, *, adClientId: str, body: UrlChannel = ..., **kwargs: typing.Any
        ) -> UrlChannelHttpRequest: ...
        def list(
            self,
            *,
            adClientId: str,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> UrlChannelsHttpRequest: ...
        def list_next(
            self,
            previous_request: UrlChannelsHttpRequest,
            previous_response: UrlChannels,
        ) -> UrlChannelsHttpRequest | None: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def accounts(self) -> AccountsResource: ...
    def adclients(self) -> AdclientsResource: ...
    def associationsessions(self) -> AssociationsessionsResource: ...
    def customchannels(self) -> CustomchannelsResource: ...
    def reports(self) -> ReportsResource: ...
    def urlchannels(self) -> UrlchannelsResource: ...

@typing.type_check_only
class AccountHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Account: ...

@typing.type_check_only
class AccountsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Accounts: ...

@typing.type_check_only
class AdClientHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AdClient: ...

@typing.type_check_only
class AdClientsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AdClients: ...

@typing.type_check_only
class AdCodeHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AdCode: ...

@typing.type_check_only
class AdUnitHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AdUnit: ...

@typing.type_check_only
class AdUnitsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AdUnits: ...

@typing.type_check_only
class AssociationSessionHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AssociationSession: ...

@typing.type_check_only
class CustomChannelHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CustomChannel: ...

@typing.type_check_only
class CustomChannelsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CustomChannels: ...

@typing.type_check_only
class ReportHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Report: ...

@typing.type_check_only
class UrlChannelHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> UrlChannel: ...

@typing.type_check_only
class UrlChannelsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> UrlChannels: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class GoogleCloudPolicysimulatorV1Replay(typing_extensions.TypedDict, total=False):
    config: GoogleCloudPolicysimulatorV1ReplayConfig
    name: str
    resultsSummary: GoogleCloudPolicysimulatorV1ReplayResultsSummary
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "PENDING", "RUNNING", "SUCCEEDED", "FAILED"
    ]

@typing.type_check_only
class GoogleCloudPolicysimulatorV1ReplayConfig(
    typing_extensions.TypedDict, total=False
):
    logSource: typing_extensions.Literal["LOG_SOURCE_UNSPECIFIED", "RECENT_ACCESSES"]
    policyOverlay: dict[str, typing.Any]

@typing.type_check_only
class GoogleCloudPolicysimulatorV1ReplayOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    startTime: str

@typing.type_check_only
class GoogleCloudPolicysimulatorV1ReplayResultsSummary(
    typing_extensions.TypedDict, total=False
):
    differenceCount: int
    errorCount: int
    logCount: int
    newestDate: GoogleTypeDate
    oldestDate: GoogleTypeDate
    unchangedCount: int

@typing.type_check_only
class GoogleCloudPolicysimulatorV1beta1Replay(typing_extensions.TypedDict, total=False):
    config: GoogleCloudPolicysimulatorV1beta1ReplayConfig
    name: str
    resultsSummary: GoogleCloudPolicysimulatorV1beta1ReplayResultsSummary
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "PENDING", "RUNNING", "SUCCEEDED", "FAILED"
    ]

@typing.type_check_only
class GoogleCloudPolicysimulatorV1beta1ReplayConfig(
    typing_extensions.TypedDict, total=False
):
    logSource: typing_extensions.Literal["LOG_SOURCE_UNSPECIFIED", "RECENT_ACCESSES"]
    policyOverlay: dict[str, typing.Any]

@typing.type_check_only
class GoogleCloudPolicysimulatorV1beta1ReplayOperationMetadata(
    typing_extensions.TypedDict, total=False
):
    startTime: str

@typing.type_check_only
class GoogleCloudPolicysimulatorV1beta1ReplayResultsSummary(
    typing_extensions.TypedDict, total=False
):
    differenceCount: int
    errorCount: int
    logCount: int
    newestDate: GoogleTypeDate
    oldestDate: GoogleTypeDate
    unchangedCount: int

@typing.type_check_only
class GoogleIamV1AuditConfig(typing_extensions.TypedDict, total=False):
    auditLogConfigs: _list[GoogleIamV1AuditLogConfig]
    service: str

@typing.type_check_only
class GoogleIamV1AuditLogConfig(typing_extensions.TypedDict, total=False):
    exemptedMembers: _list[str]
    logType: typing_extensions.Literal[
        "LOG_TYPE_UNSPECIFIED", "ADMIN_READ", "DATA_WRITE", "DATA_READ"
    ]

@typing.type_check_only
class GoogleIamV1Binding(typing_extensions.TypedDict, total=False):
    condition: GoogleTypeExpr
    members: _list[str]
    role: str

@typing.type_check_only
class GoogleIamV1Policy(typing_extensions.TypedDict, total=False):
    auditConfigs: _list[GoogleIamV1AuditConfig]
    bindings: _list[GoogleIamV1Binding]
    etag: str
    version: int

@typing.type_check_only
class GoogleLongrunningListOperationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    operations: _list[GoogleLongrunningOperation]

@typing.type_check_only
class GoogleLongrunningOperation(typing_extensions.TypedDict, total=False):
    done: bool
    error: GoogleRpcStatus
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class GoogleRpcStatus(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class GoogleTypeDate(typing_extensions.TypedDict, total=False):
    day: int
    month: int
    year: int

@typing.type_check_only
class GoogleTypeExpr(typing_extensions.TypedDict, total=False):
    description: str
    expression: str
    location: str
    title: str



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class SpeechResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class OperationsResource(googleapiclient.discovery.Resource):
        def get(self, *, name: str, **kwargs: typing.Any) -> OperationHttpRequest: ...
        def list(
            self,
            *,
            filter: str = ...,
            name: str = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> ListOperationsResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListOperationsResponseHttpRequest,
            previous_response: ListOperationsResponse,
        ) -> ListOperationsResponseHttpRequest | None: ...

    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class CustomClassesResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: CreateCustomClassRequest = ...,
                    **kwargs: typing.Any
                ) -> CustomClassHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> CustomClassHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListCustomClassesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListCustomClassesResponseHttpRequest,
                    previous_response: ListCustomClassesResponse,
                ) -> ListCustomClassesResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: CustomClass = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> CustomClassHttpRequest: ...

            @typing.type_check_only
            class PhraseSetsResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: CreatePhraseSetRequest = ...,
                    **kwargs: typing.Any
                ) -> PhraseSetHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> PhraseSetHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListPhraseSetResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListPhraseSetResponseHttpRequest,
                    previous_response: ListPhraseSetResponse,
                ) -> ListPhraseSetResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: PhraseSet = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> PhraseSetHttpRequest: ...

            def customClasses(self) -> CustomClassesResource: ...
            def phraseSets(self) -> PhraseSetsResource: ...

        def locations(self) -> LocationsResource: ...

    @typing.type_check_only
    class SpeechResource(googleapiclient.discovery.Resource):
        def longrunningrecognize(
            self, *, body: LongRunningRecognizeRequest = ..., **kwargs: typing.Any
        ) -> OperationHttpRequest: ...
        def recognize(
            self, *, body: RecognizeRequest = ..., **kwargs: typing.Any
        ) -> RecognizeResponseHttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def operations(self) -> OperationsResource: ...
    def projects(self) -> ProjectsResource: ...
    def speech(self) -> SpeechResource: ...

@typing.type_check_only
class CustomClassHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CustomClass: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class ListCustomClassesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListCustomClassesResponse: ...

@typing.type_check_only
class ListOperationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListOperationsResponse: ...

@typing.type_check_only
class ListPhraseSetResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListPhraseSetResponse: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...

@typing.type_check_only
class PhraseSetHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PhraseSet: ...

@typing.type_check_only
class RecognizeResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> RecognizeResponse: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class AdsenseResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class AccountsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class AdclientsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class AdunitsResource(googleapiclient.discovery.Resource):
                def create(
                    self, *, parent: str, body: AdUnit = ..., **kwargs: typing.Any
                ) -> AdUnitHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> AdUnitHttpRequest: ...
                def getAdcode(
                    self, *, name: str, **kwargs: typing.Any
                ) -> AdUnitAdCodeHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListAdUnitsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListAdUnitsResponseHttpRequest,
                    previous_response: ListAdUnitsResponse,
                ) -> ListAdUnitsResponseHttpRequest | None: ...
                def listLinkedCustomChannels(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListLinkedCustomChannelsResponseHttpRequest: ...
                def listLinkedCustomChannels_next(
                    self,
                    previous_request: ListLinkedCustomChannelsResponseHttpRequest,
                    previous_response: ListLinkedCustomChannelsResponse,
                ) -> ListLinkedCustomChannelsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: AdUnit = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> AdUnitHttpRequest: ...

            @typing.type_check_only
            class CustomchannelsResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: CustomChannel = ...,
                    **kwargs: typing.Any
                ) -> CustomChannelHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> CustomChannelHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListCustomChannelsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListCustomChannelsResponseHttpRequest,
                    previous_response: ListCustomChannelsResponse,
                ) -> ListCustomChannelsResponseHttpRequest | None: ...
                def listLinkedAdUnits(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListLinkedAdUnitsResponseHttpRequest: ...
                def listLinkedAdUnits_next(
                    self,
                    previous_request: ListLinkedAdUnitsResponseHttpRequest,
                    previous_response: ListLinkedAdUnitsResponse,
                ) -> ListLinkedAdUnitsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: CustomChannel = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> CustomChannelHttpRequest: ...

            @typing.type_check_only
            class UrlchannelsResource(googleapiclient.discovery.Resource):
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> UrlChannelHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListUrlChannelsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListUrlChannelsResponseHttpRequest,
                    previous_response: ListUrlChannelsResponse,
                ) -> ListUrlChannelsResponseHttpRequest | None: ...

            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> AdClientHttpRequest: ...
            def getAdcode(
                self, *, name: str, **kwargs: typing.Any
            ) -> AdClientAdCodeHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListAdClientsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListAdClientsResponseHttpRequest,
                previous_response: ListAdClientsResponse,
            ) -> ListAdClientsResponseHttpRequest | None: ...
            def adunits(self) -> AdunitsResource: ...
            def customchannels(self) -> CustomchannelsResource: ...
            def urlchannels(self) -> UrlchannelsResource: ...

        @typing.type_check_only
        class AlertsResource(googleapiclient.discovery.Resource):
            def list(
                self, *, parent: str, languageCode: str = ..., **kwargs: typing.Any
            ) -> ListAlertsResponseHttpRequest: ...

        @typing.type_check_only
        class PaymentsResource(googleapiclient.discovery.Resource):
            def list(
                self, *, parent: str, **kwargs: typing.Any
            ) -> ListPaymentsResponseHttpRequest: ...

        @typing.type_check_only
        class ReportsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class SavedResource(googleapiclient.discovery.Resource):
                def generate(
                    self,
                    *,
                    name: str,
                    currencyCode: str = ...,
                    dateRange: typing_extensions.Literal[
                        "REPORTING_DATE_RANGE_UNSPECIFIED",
                        "CUSTOM",
                        "TODAY",
                        "YESTERDAY",
                        "MONTH_TO_DATE",
                        "YEAR_TO_DATE",
                        "LAST_7_DAYS",
                        "LAST_30_DAYS",
                    ] = ...,
                    endDate_day: int = ...,
                    endDate_month: int = ...,
                    endDate_year: int = ...,
                    languageCode: str = ...,
                    reportingTimeZone: typing_extensions.Literal[
                        "REPORTING_TIME_ZONE_UNSPECIFIED",
                        "ACCOUNT_TIME_ZONE",
                        "GOOGLE_TIME_ZONE",
                    ] = ...,
                    startDate_day: int = ...,
                    startDate_month: int = ...,
                    startDate_year: int = ...,
                    **kwargs: typing.Any
                ) -> ReportResultHttpRequest: ...
                def generateCsv(
                    self,
                    *,
                    name: str,
                    currencyCode: str = ...,
                    dateRange: typing_extensions.Literal[
                        "REPORTING_DATE_RANGE_UNSPECIFIED",
                        "CUSTOM",
                        "TODAY",
                        "YESTERDAY",
                        "MONTH_TO_DATE",
                        "YEAR_TO_DATE",
                        "LAST_7_DAYS",
                        "LAST_30_DAYS",
                    ] = ...,
                    endDate_day: int = ...,
                    endDate_month: int = ...,
                    endDate_year: int = ...,
                    languageCode: str = ...,
                    reportingTimeZone: typing_extensions.Literal[
                        "REPORTING_TIME_ZONE_UNSPECIFIED",
                        "ACCOUNT_TIME_ZONE",
                        "GOOGLE_TIME_ZONE",
                    ] = ...,
                    startDate_day: int = ...,
                    startDate_month: int = ...,
                    startDate_year: int = ...,
                    **kwargs: typing.Any
                ) -> HttpBodyHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListSavedReportsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListSavedReportsResponseHttpRequest,
                    previous_response: ListSavedReportsResponse,
                ) -> ListSavedReportsResponseHttpRequest | None: ...

            def generate(
                self,
                *,
                account: str,
                currencyCode: str = ...,
                dateRange: typing_extensions.Literal[
                    "REPORTING_DATE_RANGE_UNSPECIFIED",
                    "CUSTOM",
                    "TODAY",
                    "YESTERDAY",
                    "MONTH_TO_DATE",
                    "YEAR_TO_DATE",
                    "LAST_7_DAYS",
                    "LAST_30_DAYS",
                ] = ...,
                dimensions: typing_extensions.Literal[
                    "DIMENSION_UNSPECIFIED",
                    "DATE",
                    "WEEK",
                    "MONTH",
                    "ACCOUNT_NAME",
                    "AD_CLIENT_ID",
                    "HOSTED_AD_CLIENT_ID",
                    "PRODUCT_NAME",
                    "PRODUCT_CODE",
                    "AD_UNIT_NAME",
                    "AD_UNIT_ID",
                    "AD_UNIT_SIZE_NAME",
                    "AD_UNIT_SIZE_CODE",
                    "CUSTOM_CHANNEL_NAME",
                    "CUSTOM_CHANNEL_ID",
                    "OWNED_SITE_DOMAIN_NAME",
                    "OWNED_SITE_ID",
                    "URL_CHANNEL_NAME",
                    "URL_CHANNEL_ID",
                    "BUYER_NETWORK_NAME",
                    "BUYER_NETWORK_ID",
                    "BID_TYPE_NAME",
                    "BID_TYPE_CODE",
                    "CREATIVE_SIZE_NAME",
                    "CREATIVE_SIZE_CODE",
                    "DOMAIN_NAME",
                    "DOMAIN_CODE",
                    "COUNTRY_NAME",
                    "COUNTRY_CODE",
                    "PLATFORM_TYPE_NAME",
                    "PLATFORM_TYPE_CODE",
                    "TARGETING_TYPE_NAME",
                    "TARGETING_TYPE_CODE",
                    "CONTENT_PLATFORM_NAME",
                    "CONTENT_PLATFORM_CODE",
                    "AD_PLACEMENT_NAME",
                    "AD_PLACEMENT_CODE",
                    "REQUESTED_AD_TYPE_NAME",
                    "REQUESTED_AD_TYPE_CODE",
                    "SERVED_AD_TYPE_NAME",
                    "SERVED_AD_TYPE_CODE",
                    "AD_FORMAT_NAME",
                    "AD_FORMAT_CODE",
                    "CUSTOM_SEARCH_STYLE_NAME",
                    "CUSTOM_SEARCH_STYLE_ID",
                    "DOMAIN_REGISTRANT",
                    "WEBSEARCH_QUERY_STRING",
                ]
                | _list[
                    typing_extensions.Literal[
                        "DIMENSION_UNSPECIFIED",
                        "DATE",
                        "WEEK",
                        "MONTH",
                        "ACCOUNT_NAME",
                        "AD_CLIENT_ID",
                        "HOSTED_AD_CLIENT_ID",
                        "PRODUCT_NAME",
                        "PRODUCT_CODE",
                        "AD_UNIT_NAME",
                        "AD_UNIT_ID",
                        "AD_UNIT_SIZE_NAME",
                        "AD_UNIT_SIZE_CODE",
                        "CUSTOM_CHANNEL_NAME",
                        "CUSTOM_CHANNEL_ID",
                        "OWNED_SITE_DOMAIN_NAME",
                        "OWNED_SITE_ID",
                        "URL_CHANNEL_NAME",
                        "URL_CHANNEL_ID",
                        "BUYER_NETWORK_NAME",
                        "BUYER_NETWORK_ID",
                        "BID_TYPE_NAME",
                        "BID_TYPE_CODE",
                        "CREATIVE_SIZE_NAME",
                        "CREATIVE_SIZE_CODE",
                        "DOMAIN_NAME",
                        "DOMAIN_CODE",
                        "COUNTRY_NAME",
                        "COUNTRY_CODE",
                        "PLATFORM_TYPE_NAME",
                        "PLATFORM_TYPE_CODE",
                        "TARGETING_TYPE_NAME",
                        "TARGETING_TYPE_CODE",
                        "CONTENT_PLATFORM_NAME",
                        "CONTENT_PLATFORM_CODE",
                        "AD_PLACEMENT_NAME",
                        "AD_PLACEMENT_CODE",
                        "REQUESTED_AD_TYPE_NAME",
                        "REQUESTED_AD_TYPE_CODE",
                        "SERVED_AD_TYPE_NAME",
                        "SERVED_AD_TYPE_CODE",
                        "AD_FORMAT_NAME",
                        "AD_FORMAT_CODE",
                        "CUSTOM_SEARCH_STYLE_NAME",
                        "CUSTOM_SEARCH_STYLE_ID",
                        "DOMAIN_REGISTRANT",
                        "WEBSEARCH_QUERY_STRING",
                    ]
                ] = ...,
                endDate_day: int = ...,
                endDate_month: int = ...,
                endDate_year: int = ...,
                filters: str | _list[str] = ...,
                languageCode: str = ...,
                limit: int = ...,
                metrics: typing_extensions.Literal[
                    "METRIC_UNSPECIFIED",
                    "PAGE_VIEWS",
                    "AD_REQUESTS",
                    "MATCHED_AD_REQUESTS",
                    "TOTAL_IMPRESSIONS",
                    "IMPRESSIONS",
                    "INDIVIDUAL_AD_IMPRESSIONS",
                    "CLICKS",
                    "PAGE_VIEWS_SPAM_RATIO",
                    "AD_REQUESTS_SPAM_RATIO",
                    "MATCHED_AD_REQUESTS_SPAM_RATIO",
                    "IMPRESSIONS_SPAM_RATIO",
                    "INDIVIDUAL_AD_IMPRESSIONS_SPAM_RATIO",
                    "CLICKS_SPAM_RATIO",
                    "AD_REQUESTS_COVERAGE",
                    "PAGE_VIEWS_CTR",
                    "AD_REQUESTS_CTR",
                    "MATCHED_AD_REQUESTS_CTR",
                    "IMPRESSIONS_CTR",
                    "INDIVIDUAL_AD_IMPRESSIONS_CTR",
                    "ACTIVE_VIEW_MEASURABILITY",
                    "ACTIVE_VIEW_VIEWABILITY",
                    "ACTIVE_VIEW_TIME",
                    "ESTIMATED_EARNINGS",
                    "PAGE_VIEWS_RPM",
                    "AD_REQUESTS_RPM",
                    "MATCHED_AD_REQUESTS_RPM",
                    "IMPRESSIONS_RPM",
                    "INDIVIDUAL_AD_IMPRESSIONS_RPM",
                    "COST_PER_CLICK",
                    "ADS_PER_IMPRESSION",
                    "TOTAL_EARNINGS",
                    "WEBSEARCH_RESULT_PAGES",
                ]
                | _list[
                    typing_extensions.Literal[
                        "METRIC_UNSPECIFIED",
                        "PAGE_VIEWS",
                        "AD_REQUESTS",
                        "MATCHED_AD_REQUESTS",
                        "TOTAL_IMPRESSIONS",
                        "IMPRESSIONS",
                        "INDIVIDUAL_AD_IMPRESSIONS",
                        "CLICKS",
                        "PAGE_VIEWS_SPAM_RATIO",
                        "AD_REQUESTS_SPAM_RATIO",
                        "MATCHED_AD_REQUESTS_SPAM_RATIO",
                        "IMPRESSIONS_SPAM_RATIO",
                        "INDIVIDUAL_AD_IMPRESSIONS_SPAM_RATIO",
                        "CLICKS_SPAM_RATIO",
                        "AD_REQUESTS_COVERAGE",
                        "PAGE_VIEWS_CTR",
                        "AD_REQUESTS_CTR",
                        "MATCHED_AD_REQUESTS_CTR",
                        "IMPRESSIONS_CTR",
                        "INDIVIDUAL_AD_IMPRESSIONS_CTR",
                        "ACTIVE_VIEW_MEASURABILITY",
                        "ACTIVE_VIEW_VIEWABILITY",
                        "ACTIVE_VIEW_TIME",
                        "ESTIMATED_EARNINGS",
                        "PAGE_VIEWS_RPM",
                        "AD_REQUESTS_RPM",
                        "MATCHED_AD_REQUESTS_RPM",
                        "IMPRESSIONS_RPM",
                        "INDIVIDUAL_AD_IMPRESSIONS_RPM",
                        "COST_PER_CLICK",
                        "ADS_PER_IMPRESSION",
                        "TOTAL_EARNINGS",
                        "WEBSEARCH_RESULT_PAGES",
                    ]
                ] = ...,
                orderBy: str | _list[str] = ...,
                reportingTimeZone: typing_extensions.Literal[
                    "REPORTING_TIME_ZONE_UNSPECIFIED",
                    "ACCOUNT_TIME_ZONE",
                    "GOOGLE_TIME_ZONE",
                ] = ...,
                startDate_day: int = ...,
                startDate_month: int = ...,
                startDate_year: int = ...,
                **kwargs: typing.Any
            ) -> ReportResultHttpRequest: ...
            def generateCsv(
                self,
                *,
                account: str,
                currencyCode: str = ...,
                dateRange: typing_extensions.Literal[
                    "REPORTING_DATE_RANGE_UNSPECIFIED",
                    "CUSTOM",
                    "TODAY",
                    "YESTERDAY",
                    "MONTH_TO_DATE",
                    "YEAR_TO_DATE",
                    "LAST_7_DAYS",
                    "LAST_30_DAYS",
                ] = ...,
                dimensions: typing_extensions.Literal[
                    "DIMENSION_UNSPECIFIED",
                    "DATE",
                    "WEEK",
                    "MONTH",
                    "ACCOUNT_NAME",
                    "AD_CLIENT_ID",
                    "HOSTED_AD_CLIENT_ID",
                    "PRODUCT_NAME",
                    "PRODUCT_CODE",
                    "AD_UNIT_NAME",
                    "AD_UNIT_ID",
                    "AD_UNIT_SIZE_NAME",
                    "AD_UNIT_SIZE_CODE",
                    "CUSTOM_CHANNEL_NAME",
                    "CUSTOM_CHANNEL_ID",
                    "OWNED_SITE_DOMAIN_NAME",
                    "OWNED_SITE_ID",
                    "URL_CHANNEL_NAME",
                    "URL_CHANNEL_ID",
                    "BUYER_NETWORK_NAME",
                    "BUYER_NETWORK_ID",
                    "BID_TYPE_NAME",
                    "BID_TYPE_CODE",
                    "CREATIVE_SIZE_NAME",
                    "CREATIVE_SIZE_CODE",
                    "DOMAIN_NAME",
                    "DOMAIN_CODE",
                    "COUNTRY_NAME",
                    "COUNTRY_CODE",
                    "PLATFORM_TYPE_NAME",
                    "PLATFORM_TYPE_CODE",
                    "TARGETING_TYPE_NAME",
                    "TARGETING_TYPE_CODE",
                    "CONTENT_PLATFORM_NAME",
                    "CONTENT_PLATFORM_CODE",
                    "AD_PLACEMENT_NAME",
                    "AD_PLACEMENT_CODE",
                    "REQUESTED_AD_TYPE_NAME",
                    "REQUESTED_AD_TYPE_CODE",
                    "SERVED_AD_TYPE_NAME",
                    "SERVED_AD_TYPE_CODE",
                    "AD_FORMAT_NAME",
                    "AD_FORMAT_CODE",
                    "CUSTOM_SEARCH_STYLE_NAME",
                    "CUSTOM_SEARCH_STYLE_ID",
                    "DOMAIN_REGISTRANT",
                    "WEBSEARCH_QUERY_STRING",
                ]
                | _list[
                    typing_extensions.Literal[
                        "DIMENSION_UNSPECIFIED",
                        "DATE",
                        "WEEK",
                        "MONTH",
                        "ACCOUNT_NAME",
                        "AD_CLIENT_ID",
                        "HOSTED_AD_CLIENT_ID",
                        "PRODUCT_NAME",
                        "PRODUCT_CODE",
                        "AD_UNIT_NAME",
                        "AD_UNIT_ID",
                        "AD_UNIT_SIZE_NAME",
                        "AD_UNIT_SIZE_CODE",
                        "CUSTOM_CHANNEL_NAME",
                        "CUSTOM_CHANNEL_ID",
                        "OWNED_SITE_DOMAIN_NAME",
                        "OWNED_SITE_ID",
                        "URL_CHANNEL_NAME",
                        "URL_CHANNEL_ID",
                        "BUYER_NETWORK_NAME",
                        "BUYER_NETWORK_ID",
                        "BID_TYPE_NAME",
                        "BID_TYPE_CODE",
                        "CREATIVE_SIZE_NAME",
                        "CREATIVE_SIZE_CODE",
                        "DOMAIN_NAME",
                        "DOMAIN_CODE",
                        "COUNTRY_NAME",
                        "COUNTRY_CODE",
                        "PLATFORM_TYPE_NAME",
                        "PLATFORM_TYPE_CODE",
                        "TARGETING_TYPE_NAME",
                        "TARGETING_TYPE_CODE",
                        "CONTENT_PLATFORM_NAME",
                        "CONTENT_PLATFORM_CODE",
                        "AD_PLACEMENT_NAME",
                        "AD_PLACEMENT_CODE",
                        "REQUESTED_AD_TYPE_NAME",
                        "REQUESTED_AD_TYPE_CODE",
                        "SERVED_AD_TYPE_NAME",
                        "SERVED_AD_TYPE_CODE",
                        "AD_FORMAT_NAME",
                        "AD_FORMAT_CODE",
                        "CUSTOM_SEARCH_STYLE_NAME",
                        "CUSTOM_SEARCH_STYLE_ID",
                        "DOMAIN_REGISTRANT",
                        "WEBSEARCH_QUERY_STRING",
                    ]
                ] = ...,
                endDate_day: int = ...,
                endDate_month: int = ...,
                endDate_year: int = ...,
                filters: str | _list[str] = ...,
                languageCode: str = ...,
                limit: int = ...,
                metrics: typing_extensions.Literal[
                    "METRIC_UNSPECIFIED",
                    "PAGE_VIEWS",
                    "AD_REQUESTS",
                    "MATCHED_AD_REQUESTS",
                    "TOTAL_IMPRESSIONS",
                    "IMPRESSIONS",
                    "INDIVIDUAL_AD_IMPRESSIONS",
                    "CLICKS",
                    "PAGE_VIEWS_SPAM_RATIO",
                    "AD_REQUESTS_SPAM_RATIO",
                    "MATCHED_AD_REQUESTS_SPAM_RATIO",
                    "IMPRESSIONS_SPAM_RATIO",
                    "INDIVIDUAL_AD_IMPRESSIONS_SPAM_RATIO",
                    "CLICKS_SPAM_RATIO",
                    "AD_REQUESTS_COVERAGE",
                    "PAGE_VIEWS_CTR",
                    "AD_REQUESTS_CTR",
                    "MATCHED_AD_REQUESTS_CTR",
                    "IMPRESSIONS_CTR",
                    "INDIVIDUAL_AD_IMPRESSIONS_CTR",
                    "ACTIVE_VIEW_MEASURABILITY",
                    "ACTIVE_VIEW_VIEWABILITY",
                    "ACTIVE_VIEW_TIME",
                    "ESTIMATED_EARNINGS",
                    "PAGE_VIEWS_RPM",
                    "AD_REQUESTS_RPM",
                    "MATCHED_AD_REQUESTS_RPM",
                    "IMPRESSIONS_RPM",
                    "INDIVIDUAL_AD_IMPRESSIONS_RPM",
                    "COST_PER_CLICK",
                    "ADS_PER_IMPRESSION",
                    "TOTAL_EARNINGS",
                    "WEBSEARCH_RESULT_PAGES",
                ]
                | _list[
                    typing_extensions.Literal[
                        "METRIC_UNSPECIFIED",
                        "PAGE_VIEWS",
                        "AD_REQUESTS",
                        "MATCHED_AD_REQUESTS",
                        "TOTAL_IMPRESSIONS",
                        "IMPRESSIONS",
                        "INDIVIDUAL_AD_IMPRESSIONS",
                        "CLICKS",
                        "PAGE_VIEWS_SPAM_RATIO",
                        "AD_REQUESTS_SPAM_RATIO",
                        "MATCHED_AD_REQUESTS_SPAM_RATIO",
                        "IMPRESSIONS_SPAM_RATIO",
                        "INDIVIDUAL_AD_IMPRESSIONS_SPAM_RATIO",
                        "CLICKS_SPAM_RATIO",
                        "AD_REQUESTS_COVERAGE",
                        "PAGE_VIEWS_CTR",
                        "AD_REQUESTS_CTR",
                        "MATCHED_AD_REQUESTS_CTR",
                        "IMPRESSIONS_CTR",
                        "INDIVIDUAL_AD_IMPRESSIONS_CTR",
                        "ACTIVE_VIEW_MEASURABILITY",
                        "ACTIVE_VIEW_VIEWABILITY",
                        "ACTIVE_VIEW_TIME",
                        "ESTIMATED_EARNINGS",
                        "PAGE_VIEWS_RPM",
                        "AD_REQUESTS_RPM",
                        "MATCHED_AD_REQUESTS_RPM",
                        "IMPRESSIONS_RPM",
                        "INDIVIDUAL_AD_IMPRESSIONS_RPM",
                        "COST_PER_CLICK",
                        "ADS_PER_IMPRESSION",
                        "TOTAL_EARNINGS",
                        "WEBSEARCH_RESULT_PAGES",
                    ]
                ] = ...,
                orderBy: str | _list[str] = ...,
                reportingTimeZone: typing_extensions.Literal[
                    "REPORTING_TIME_ZONE_UNSPECIFIED",
                    "ACCOUNT_TIME_ZONE",
                    "GOOGLE_TIME_ZONE",
                ] = ...,
                startDate_day: int = ...,
                startDate_month: int = ...,
                startDate_year: int = ...,
                **kwargs: typing.Any
            ) -> HttpBodyHttpRequest: ...
            def getSaved(
                self, *, name: str, **kwargs: typing.Any
            ) -> SavedReportHttpRequest: ...
            def saved(self) -> SavedResource: ...

        @typing.type_check_only
        class SitesResource(googleapiclient.discovery.Resource):
            def get(self, *, name: str, **kwargs: typing.Any) -> SiteHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListSitesResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListSitesResponseHttpRequest,
                previous_response: ListSitesResponse,
            ) -> ListSitesResponseHttpRequest | None: ...

        def get(self, *, name: str, **kwargs: typing.Any) -> AccountHttpRequest: ...
        def getAdBlockingRecoveryTag(
            self, *, name: str, **kwargs: typing.Any
        ) -> AdBlockingRecoveryTagHttpRequest: ...
        def list(
            self, *, pageSize: int = ..., pageToken: str = ..., **kwargs: typing.Any
        ) -> ListAccountsResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListAccountsResponseHttpRequest,
            previous_response: ListAccountsResponse,
        ) -> ListAccountsResponseHttpRequest | None: ...
        def listChildAccounts(
            self,
            *,
            parent: str,
            pageSize: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> ListChildAccountsResponseHttpRequest: ...
        def listChildAccounts_next(
            self,
            previous_request: ListChildAccountsResponseHttpRequest,
            previous_response: ListChildAccountsResponse,
        ) -> ListChildAccountsResponseHttpRequest | None: ...
        def adclients(self) -> AdclientsResource: ...
        def alerts(self) -> AlertsResource: ...
        def payments(self) -> PaymentsResource: ...
        def reports(self) -> ReportsResource: ...
        def sites(self) -> SitesResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def accounts(self) -> AccountsResource: ...

@typing.type_check_only
class AccountHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Account: ...

@typing.type_check_only
class AdBlockingRecoveryTagHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AdBlockingRecoveryTag: ...

@typing.type_check_only
class AdClientHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AdClient: ...

@typing.type_check_only
class AdClientAdCodeHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AdClientAdCode: ...

@typing.type_check_only
class AdUnitHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AdUnit: ...

@typing.type_check_only
class AdUnitAdCodeHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AdUnitAdCode: ...

@typing.type_check_only
class CustomChannelHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CustomChannel: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class HttpBodyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> HttpBody: ...

@typing.type_check_only
class ListAccountsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListAccountsResponse: ...

@typing.type_check_only
class ListAdClientsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListAdClientsResponse: ...

@typing.type_check_only
class ListAdUnitsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListAdUnitsResponse: ...

@typing.type_check_only
class ListAlertsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListAlertsResponse: ...

@typing.type_check_only
class ListChildAccountsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListChildAccountsResponse: ...

@typing.type_check_only
class ListCustomChannelsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListCustomChannelsResponse: ...

@typing.type_check_only
class ListLinkedAdUnitsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListLinkedAdUnitsResponse: ...

@typing.type_check_only
class ListLinkedCustomChannelsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListLinkedCustomChannelsResponse: ...

@typing.type_check_only
class ListPaymentsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListPaymentsResponse: ...

@typing.type_check_only
class ListSavedReportsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListSavedReportsResponse: ...

@typing.type_check_only
class ListSitesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListSitesResponse: ...

@typing.type_check_only
class ListUrlChannelsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListUrlChannelsResponse: ...

@typing.type_check_only
class ReportResultHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ReportResult: ...

@typing.type_check_only
class SavedReportHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SavedReport: ...

@typing.type_check_only
class SiteHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Site: ...

@typing.type_check_only
class UrlChannelHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> UrlChannel: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class PlaydeveloperreportingResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class AnomaliesResource(googleapiclient.discovery.Resource):
        def list(
            self,
            *,
            parent: str,
            filter: str = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> GooglePlayDeveloperReportingV1alpha1ListAnomaliesResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: GooglePlayDeveloperReportingV1alpha1ListAnomaliesResponseHttpRequest,
            previous_response: GooglePlayDeveloperReportingV1alpha1ListAnomaliesResponse,
        ) -> GooglePlayDeveloperReportingV1alpha1ListAnomaliesResponseHttpRequest | None: ...

    @typing.type_check_only
    class VitalsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class AnrrateResource(googleapiclient.discovery.Resource):
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GooglePlayDeveloperReportingV1alpha1AnrRateMetricSetHttpRequest: ...
            def query(
                self,
                *,
                name: str,
                body: GooglePlayDeveloperReportingV1alpha1QueryAnrRateMetricSetRequest = ...,
                **kwargs: typing.Any
            ) -> GooglePlayDeveloperReportingV1alpha1QueryAnrRateMetricSetResponseHttpRequest: ...
            def query_next(
                self,
                previous_request: GooglePlayDeveloperReportingV1alpha1QueryAnrRateMetricSetResponseHttpRequest,
                previous_response: GooglePlayDeveloperReportingV1alpha1QueryAnrRateMetricSetResponse,
            ) -> GooglePlayDeveloperReportingV1alpha1QueryAnrRateMetricSetResponseHttpRequest | None: ...

        @typing.type_check_only
        class CrashrateResource(googleapiclient.discovery.Resource):
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GooglePlayDeveloperReportingV1alpha1CrashRateMetricSetHttpRequest: ...
            def query(
                self,
                *,
                name: str,
                body: GooglePlayDeveloperReportingV1alpha1QueryCrashRateMetricSetRequest = ...,
                **kwargs: typing.Any
            ) -> GooglePlayDeveloperReportingV1alpha1QueryCrashRateMetricSetResponseHttpRequest: ...
            def query_next(
                self,
                previous_request: GooglePlayDeveloperReportingV1alpha1QueryCrashRateMetricSetResponseHttpRequest,
                previous_response: GooglePlayDeveloperReportingV1alpha1QueryCrashRateMetricSetResponse,
            ) -> GooglePlayDeveloperReportingV1alpha1QueryCrashRateMetricSetResponseHttpRequest | None: ...

        @typing.type_check_only
        class ErrorsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class CountsResource(googleapiclient.discovery.Resource):
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GooglePlayDeveloperReportingV1alpha1ErrorCountMetricSetHttpRequest: ...
                def query(
                    self,
                    *,
                    name: str,
                    body: GooglePlayDeveloperReportingV1alpha1QueryErrorCountMetricSetRequest = ...,
                    **kwargs: typing.Any
                ) -> GooglePlayDeveloperReportingV1alpha1QueryErrorCountMetricSetResponseHttpRequest: ...
                def query_next(
                    self,
                    previous_request: GooglePlayDeveloperReportingV1alpha1QueryErrorCountMetricSetResponseHttpRequest,
                    previous_response: GooglePlayDeveloperReportingV1alpha1QueryErrorCountMetricSetResponse,
                ) -> GooglePlayDeveloperReportingV1alpha1QueryErrorCountMetricSetResponseHttpRequest | None: ...

            @typing.type_check_only
            class IssuesResource(googleapiclient.discovery.Resource):
                def search(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    interval_endTime_day: int = ...,
                    interval_endTime_hours: int = ...,
                    interval_endTime_minutes: int = ...,
                    interval_endTime_month: int = ...,
                    interval_endTime_nanos: int = ...,
                    interval_endTime_seconds: int = ...,
                    interval_endTime_timeZone_id: str = ...,
                    interval_endTime_timeZone_version: str = ...,
                    interval_endTime_utcOffset: str = ...,
                    interval_endTime_year: int = ...,
                    interval_startTime_day: int = ...,
                    interval_startTime_hours: int = ...,
                    interval_startTime_minutes: int = ...,
                    interval_startTime_month: int = ...,
                    interval_startTime_nanos: int = ...,
                    interval_startTime_seconds: int = ...,
                    interval_startTime_timeZone_id: str = ...,
                    interval_startTime_timeZone_version: str = ...,
                    interval_startTime_utcOffset: str = ...,
                    interval_startTime_year: int = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GooglePlayDeveloperReportingV1alpha1SearchErrorIssuesResponseHttpRequest: ...
                def search_next(
                    self,
                    previous_request: GooglePlayDeveloperReportingV1alpha1SearchErrorIssuesResponseHttpRequest,
                    previous_response: GooglePlayDeveloperReportingV1alpha1SearchErrorIssuesResponse,
                ) -> GooglePlayDeveloperReportingV1alpha1SearchErrorIssuesResponseHttpRequest | None: ...

            @typing.type_check_only
            class ReportsResource(googleapiclient.discovery.Resource):
                def search(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    interval_endTime_day: int = ...,
                    interval_endTime_hours: int = ...,
                    interval_endTime_minutes: int = ...,
                    interval_endTime_month: int = ...,
                    interval_endTime_nanos: int = ...,
                    interval_endTime_seconds: int = ...,
                    interval_endTime_timeZone_id: str = ...,
                    interval_endTime_timeZone_version: str = ...,
                    interval_endTime_utcOffset: str = ...,
                    interval_endTime_year: int = ...,
                    interval_startTime_day: int = ...,
                    interval_startTime_hours: int = ...,
                    interval_startTime_minutes: int = ...,
                    interval_startTime_month: int = ...,
                    interval_startTime_nanos: int = ...,
                    interval_startTime_seconds: int = ...,
                    interval_startTime_timeZone_id: str = ...,
                    interval_startTime_timeZone_version: str = ...,
                    interval_startTime_utcOffset: str = ...,
                    interval_startTime_year: int = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> GooglePlayDeveloperReportingV1alpha1SearchErrorReportsResponseHttpRequest: ...
                def search_next(
                    self,
                    previous_request: GooglePlayDeveloperReportingV1alpha1SearchErrorReportsResponseHttpRequest,
                    previous_response: GooglePlayDeveloperReportingV1alpha1SearchErrorReportsResponse,
                ) -> GooglePlayDeveloperReportingV1alpha1SearchErrorReportsResponseHttpRequest | None: ...

            def counts(self) -> CountsResource: ...
            def issues(self) -> IssuesResource: ...
            def reports(self) -> ReportsResource: ...

        @typing.type_check_only
        class ExcessivewakeuprateResource(googleapiclient.discovery.Resource):
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GooglePlayDeveloperReportingV1alpha1ExcessiveWakeupRateMetricSetHttpRequest: ...
            def query(
                self,
                *,
                name: str,
                body: GooglePlayDeveloperReportingV1alpha1QueryExcessiveWakeupRateMetricSetRequest = ...,
                **kwargs: typing.Any
            ) -> GooglePlayDeveloperReportingV1alpha1QueryExcessiveWakeupRateMetricSetResponseHttpRequest: ...
            def query_next(
                self,
                previous_request: GooglePlayDeveloperReportingV1alpha1QueryExcessiveWakeupRateMetricSetResponseHttpRequest,
                previous_response: GooglePlayDeveloperReportingV1alpha1QueryExcessiveWakeupRateMetricSetResponse,
            ) -> GooglePlayDeveloperReportingV1alpha1QueryExcessiveWakeupRateMetricSetResponseHttpRequest | None: ...

        @typing.type_check_only
        class StuckbackgroundwakelockrateResource(googleapiclient.discovery.Resource):
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GooglePlayDeveloperReportingV1alpha1StuckBackgroundWakelockRateMetricSetHttpRequest: ...
            def query(
                self,
                *,
                name: str,
                body: GooglePlayDeveloperReportingV1alpha1QueryStuckBackgroundWakelockRateMetricSetRequest = ...,
                **kwargs: typing.Any
            ) -> GooglePlayDeveloperReportingV1alpha1QueryStuckBackgroundWakelockRateMetricSetResponseHttpRequest: ...
            def query_next(
                self,
                previous_request: GooglePlayDeveloperReportingV1alpha1QueryStuckBackgroundWakelockRateMetricSetResponseHttpRequest,
                previous_response: GooglePlayDeveloperReportingV1alpha1QueryStuckBackgroundWakelockRateMetricSetResponse,
            ) -> GooglePlayDeveloperReportingV1alpha1QueryStuckBackgroundWakelockRateMetricSetResponseHttpRequest | None: ...

        def anrrate(self) -> AnrrateResource: ...
        def crashrate(self) -> CrashrateResource: ...
        def errors(self) -> ErrorsResource: ...
        def excessivewakeuprate(self) -> ExcessivewakeuprateResource: ...
        def stuckbackgroundwakelockrate(
            self,
        ) -> StuckbackgroundwakelockrateResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def anomalies(self) -> AnomaliesResource: ...
    def vitals(self) -> VitalsResource: ...

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1AnrRateMetricSetHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePlayDeveloperReportingV1alpha1AnrRateMetricSet: ...

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1CrashRateMetricSetHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePlayDeveloperReportingV1alpha1CrashRateMetricSet: ...

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1ErrorCountMetricSetHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePlayDeveloperReportingV1alpha1ErrorCountMetricSet: ...

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1ExcessiveWakeupRateMetricSetHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePlayDeveloperReportingV1alpha1ExcessiveWakeupRateMetricSet: ...

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1ListAnomaliesResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePlayDeveloperReportingV1alpha1ListAnomaliesResponse: ...

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1QueryAnrRateMetricSetResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePlayDeveloperReportingV1alpha1QueryAnrRateMetricSetResponse: ...

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1QueryCrashRateMetricSetResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePlayDeveloperReportingV1alpha1QueryCrashRateMetricSetResponse: ...

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1QueryErrorCountMetricSetResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePlayDeveloperReportingV1alpha1QueryErrorCountMetricSetResponse: ...

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1QueryExcessiveWakeupRateMetricSetResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePlayDeveloperReportingV1alpha1QueryExcessiveWakeupRateMetricSetResponse: ...

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1QueryStuckBackgroundWakelockRateMetricSetResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePlayDeveloperReportingV1alpha1QueryStuckBackgroundWakelockRateMetricSetResponse: ...

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1SearchErrorIssuesResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePlayDeveloperReportingV1alpha1SearchErrorIssuesResponse: ...

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1SearchErrorReportsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePlayDeveloperReportingV1alpha1SearchErrorReportsResponse: ...

@typing.type_check_only
class GooglePlayDeveloperReportingV1alpha1StuckBackgroundWakelockRateMetricSetHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GooglePlayDeveloperReportingV1alpha1StuckBackgroundWakelockRateMetricSet: ...
